------------------------------------------------------------------------------
--									Tooltip support							--
------------------------------------------------------------------------------
local Tooltip =  FlexBar2:NewModule("Tooltip");
-- If this var is incremented, SetDefaults() will be called for this module thus resetting all its settings.
Tooltip.Version = 1;

Tooltip.ButtonMixin = {};

function Tooltip.ButtonMixin:Deactivate()
	self:DisableTooltip();
end

function Tooltip.ButtonMixin:SetDefaults()
	self.InfoTable.ShowTooltip = true;
end

function Tooltip.ButtonMixin:LoadSettings()
	if(self.InfoTable.ShowTooltip == true) then
		self:EnableTooltip();
	else
		self:DisableTooltip();
	end	
end

function Tooltip.ButtonMixin:EnableTooltip()
	self:RegisterScript("OnEnter","ShowTooltip");
	self:RegisterScript("OnLeave","HideTooltip");
end

function Tooltip.ButtonMixin:DisableTooltip()
	self:UnregisterScript("OnEnter","ShowTooltip");
	self:UnregisterScript("OnLeave","HideTooltip");
end

function Tooltip.ButtonMixin:ShowTooltip()
	GameTooltip:SetOwner(self.Frame, "ANCHOR_TOPLEFT");
	local ActionType = self:GetModifiedAttribute("type");
	-- Action on button is a spell, call SetSpell on Gametooltip
	if(ActionType == "spell") then
		local SpellSlot = FlexBar2:GetModule("SpellCache"):GetSpellInfo(self:GetModifiedAttribute("spell"));
		if(SpellSlot) then
			GameTooltip:SetText("Tooltip is buggy :(, Failed to SetSpell(", SpellSlot, ",", BOOKTYPE_SPELL, ")");
			GameTooltip:SetSpell(SpellSlot, BOOKTYPE_SPELL);
			GameTooltip:Show();
		end
	-- Action on button is an item, call SetBagItem or SetInventoryItem
	elseif(ActionType == "item") then
		local ItemInfo = FlexBar2:GetModule("ItemCache"):GetItemInfo(self:GetModifiedAttribute("item"));
		if(type(ItemInfo) == "table" and ItemInfo.Bag and ItemInfo.BagSlot) then
			GameTooltip:SetText("Tooltip is buggy :(, Failed to SetBagItem(", ItemInfo.Bag, ",", ItemInfo.BagSlot, ")");
			GameTooltip:SetBagItem(ItemInfo.Bag, ItemInfo.BagSlot);
			GameTooltip:Show();
        elseif(type(ItemInfo) == "table" and ItemInfo.InvSlot) then
			GameTooltip:SetText("Tooltip is buggy :(, Failed to SetInventoryItem(\"player\", ", ItemInfo.InvSlot, ")");
			GameTooltip:SetInventoryItem("player", ItemInfo.InvSlot);
			GameTooltip:Show();
        else
			GameTooltip:SetText("Cannot show tooltips for item not in inventory");
        end
	-- Action is a macro, call SetText with the macro's name as arg
	elseif(ActionType == "macro") then
		local Name = GetMacroInfo(self:GetModifiedAttribute("macro"));
		GameTooltip:SetText(Name);
		GameTooltip:Show();
	-- Nothing meaningfull to show, make sure tooltip is hidden
	else
		self:HideTooltip();
	end
end


function Tooltip.ButtonMixin:HideTooltip()
	GameTooltip:Hide()
end


